@@ -9,10 +9,7 @@ declare -r workdir='/mnt'
 declare -r osidir='/etc/os-installer'
 declare -r scriptsdir="$osidir/scripts/install.sh.d"
 declare -r rootlabel='arkane_root'
-
-# Load package list files
-readarray base_packages < $osidir/bits/bootstrap.list \
-	|| quit_on_err 'Failed to read base.list'
+declare -r bootlabel='arkane_boot'
 
 ## Set common functions
 #
